@@ -53,7 +53,7 @@ static Memory *Rom_getMem(SGate *);
 static SGateInfo rom_info = {
   GT_ROM,
   "rom",0x0,
-  3,{{"D",GIO_OUT,0},
+  3,{{"D",GIO_TRI,0},
      {"A",GIO_IN,0},
      {"OE",GIO_IN,0}},
 
