@@ -1,5 +1,5 @@
 /****************************************************************************
-    Copyright (C) 1987-2005 by Jeffery P. Hansen
+    Copyright (C) 1987-2007 by Jeffery P. Hansen
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    Last edit by hansen on Thu Sep  2 11:04:53 2004
+    Last edit by hansen on Thu Jan 25 21:02:56 2007
 ****************************************************************************/
 #include <stdlib.h>
 #include <string.h>
@@ -52,6 +52,7 @@ void Block_GetExtents(GCElement *g,int *minx,int *miny,int *maxx,int *maxy,int *
 GCElement *Block_Replicate(GModuleDef *,GCElement *g,int x,int y,unsigned flags);
 void Block_EditProps(GCElement *g,int isLoadDialog);
 void Block_VerSave(FILE*,GCElement*);
+void Block_Rotate(GCElement*,int,int,int rdir);
 int Block_HitDistance(GCElement*g,int,int);
 void Block_SimStateFunc(GSimModule *ss,GCElement *g);
 void Block_AddInput(EditState *es,GCElement *g);
@@ -108,6 +109,7 @@ GGateInfo gate_block_info = {
   Block_HitDistance,
   Block_Draw,
   Block_Move,
+  Block_Rotate,
   Block_Replicate,
   Block_AddInput,
   Block_AddOutput,
@@ -296,6 +298,54 @@ GCElement *Block_Make(EditState **es,GModuleDef *env,int GType,
   return g;
 }
 
+void Block_Rotate(GCElement *g,int centX, int centY,int rdir)
+{
+  int x = g->xpos + g->u.block.gwidth/2;
+  int y = g->ypos + g->u.block.gheight/2;
+  int nx,ny,t,i,j;
+
+  ob_touch(g);
+  nx = rotateX(x - centX,y - centY, rdir) + centX;
+  ny = rotateY(x - centX,y - centY, rdir) + centY;
+
+  t = g->u.block.gwidth;
+  g->u.block.gwidth = g->u.block.gheight;
+  g->u.block.gheight = t;
+
+  g->xpos = nx - g->u.block.gwidth/2;
+  g->ypos = ny - g->u.block.gheight/2;
+  
+  /*
+   * We need to shift the pads that the wires are attached to.
+   */
+  if (rdir > 0) {
+    for (j = 0;j < 3;j++) {
+      int offset = 4*j;
+      GWire *tw;
+
+      tw = g->wires[offset+3];
+      for (i = 2;i >= 0;i--) {
+	g->wires[offset+i+1] = g->wires[offset+i];
+      }
+      g->wires[offset] = tw;
+    }
+  } else {
+    for (j = 0;j < 3;j++) {
+      int offset = 4*j;
+      GWire *tw;
+
+      tw = g->wires[offset];
+      for (i = 0;i <= 2;i++) {
+	g->wires[offset+i] = g->wires[offset+i+1];
+      }
+      g->wires[offset+3] = tw;
+    }
+  }
+
+  SetModified();
+  //  SynchronizeInterface();
+}
+
 GWire *block_hitPort(GCElement *g,int x,int y)
 {
   GWire *best_w = 0;
