@@ -1,5 +1,5 @@
 /****************************************************************************
-    Copyright (C) 1987-2005 by Jeffery P. Hansen
+    Copyright (C) 1987-2007 by Jeffery P. Hansen
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    Last edit by hansen on Tue Mar  9 12:57:00 2004
+    Last edit by hansen on Sun Jan 28 14:57:01 2007
 ****************************************************************************/
 #include <stdlib.h>
 #include <stdio.h>
@@ -148,6 +148,43 @@ void Generic_Init(GCElement*g)
 {
 }
 
+GPadLoc *GCElement_getPadLoc(GCElement *g,int p,int r)
+{
+  return &g->typeinfo->Pad[p].Loc[r];
+}
+
+/*
+ * Rotate a gate 90 degree counter-clockwise around (x,y) and adjust fixed
+ * wire positions if necessary.
+ */
+void Generic_Rotate(GCElement *g, int centX, int centY,int rdir)
+{
+  int N = g->typeinfo->NumPads;
+  int x = g->xpos;
+  int y = g->ypos;
+  int i,j;
+
+  ob_touch(g);
+  g->xpos = rotateX(x - centX,y - centY,rdir) + centX;
+  g->ypos = rotateY(x - centX,y - centY,rdir) + centY;
+  g->orient = (g->orient + 4 + rdir) % 4;
+
+  for (i = 0;i < N;i++) {
+    GWire *w = g->wires[i];
+    GPadLoc *L = GCElement_getPadLoc(g,i,g->orient);
+    int x1 = L->x1 + g->xpos;
+    int y1 = L->y1 + g->ypos;
+    int x2 = L->x2 + g->xpos;
+    int y2 = L->y2 + g->ypos;
+
+    for (j = 0;w;w = w->next, j++) {
+      if (x1 == x2 && y1 == y2) {
+	wire_move(w->nodes,x1-w->nodes->x,y1-w->nodes->y,VERTICAL|HORIZONTAL);
+      }
+    }
+  }
+}
+
 void Generic_Delete(GCElement *g,GModuleDef *M,int drawp)
 {
   if (drawp) gate_draw(g,GD_NOWIRE);
@@ -324,7 +361,7 @@ void Generic_AddInput(EditState *es,GCElement *g)
   
   gate_draw(g,GD_NORMAL);
   
-  wire_addToGate(g,i,0,es->env,0);
+  wire_addToGate(g,i,es->env,0);
   gate_draw(g,GD_NORMAL);
 }
 
@@ -343,7 +380,7 @@ void Generic_AddOutput(EditState *es,GCElement *g)
   
   gate_draw(g,GD_NORMAL);
   
-  wire_addToGate(g,i,0,es->env,0);
+  wire_addToGate(g,i,es->env,0);
   gate_draw(g,GD_NORMAL);
 }
 
@@ -796,6 +833,16 @@ void gateinfo_iconInit(GGateInfo *gi,Pixmap P,iconDimensions *id,int boldOffset)
   }
 }
 
+void gateinfo_altIconInit(GGateInfo *gi,Pixmap P,iconDimensions *id,int boldOffset)
+{
+  int i;
+
+  for (i = 0;i < 4;i++) {
+    gi->altIcon[i] = Icon_register(P,id[i].x,id[i].y,id[i].w,id[i].h,id[i].ox,id[i].oy);
+    gi->altIcon[i+4] = Icon_register(P,id[i].x,id[i].y+boldOffset,id[i].w,id[i].h,id[i].ox,id[i].oy);
+  }
+}
+
 void gateinfo_1iconInit(GGateInfo *gi,Pixmap P,iconDimensions *id,int boldOffset)
 {
   int i,pid,bid;
@@ -1130,7 +1177,7 @@ void init_gates()
   init_mult();			/*  */
   init_divide();		/*  */
   init_register();		/*  */
-  init_ff();		/*  */
+  init_ff();			/*  */
   init_clock();			/*  */
   init_switch();		/*  */
   init_ground();		/*  */
