@@ -1,5 +1,5 @@
 /****************************************************************************
-    Copyright (C) 1987-2005 by Jeffery P. Hansen
+    Copyright (C) 1987-2007 by Jeffery P. Hansen
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    Last edit by hansen on Mon Dec  8 13:50:20 2003
+    Last edit by hansen on Thu Jan 25 20:45:38 2007
 ****************************************************************************/
 #include <stdlib.h>
 #include <stdio.h>
@@ -37,6 +37,7 @@ void Joint_Draw(GCElement *g,int md);
 void Joint_Delete(GCElement *g,GModuleDef *env,int drawp);
 void Joint_Init(GCElement *g);
 void Joint_VerSave(FILE *f,GCElement *g);
+void Joint_Rotate(GCElement *g, int centX, int centY, int rdir);
 
 static iconDimensions joint_iconDims[] = {
   {0, 0, 3, 3, 1, 1},
@@ -101,6 +102,7 @@ GGateInfo gate_joint_info = {
   Generic_HitDistance,
   Joint_Draw,
   Generic_Move,
+  Joint_Rotate,
   Generic_Replicate,
   Err_AddInput,
   Err_AddOutput,
@@ -141,6 +143,15 @@ void Joint_Draw(GCElement *g,int md)
   gate_drawWires(g,md);
 }
 
+void Joint_Rotate(GCElement *g, int centX, int centY,int rdir)
+{
+  int x = g->xpos;
+  int y = g->ypos;
+
+  ob_touch(g);
+  g->xpos = rotateX(x -centX,y - centY, rdir) + centX;
+  g->ypos = rotateY(x -centX,y - centY, rdir) + centY;
+}
 
 /**********************************************************************/
 /*
