@@ -1,5 +1,5 @@
 /****************************************************************************
-    Copyright (C) 1987-2005 by Jeffery P. Hansen
+    Copyright (C) 1987-2007 by Jeffery P. Hansen
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    Last edit by hansen on Fri Sep  3 14:00:19 2004
+    Last edit by hansen on Thu Jan 25 20:58:23 2007
 ****************************************************************************/
 #include "tkgate.h"
 
@@ -152,6 +152,7 @@ GGateInfo gate_led_info = {
   Generic_HitDistance,
   Led_Draw,
   Generic_Move,
+  Generic_Rotate,
   Led_Replicate,
   Generic_AddInput,
   Err_AddOutput,
