@@ -1,5 +1,5 @@
 /****************************************************************************
-    Copyright (C) 1987-2005 by Jeffery P. Hansen
+    Copyright (C) 1987-2007 by Jeffery P. Hansen
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    Last edit by hansen on Tue Jun  8 11:29:30 2004
+    Last edit by hansen on Thu Jan 25 22:15:55 2007
 ****************************************************************************/
 /*
   Functions for manageing the multi-gate selection and cut buffer.
@@ -35,6 +35,80 @@
 #include <assert.h>
 #include "tkgate.h"
 
+/*
+ * Compute the bounding box of a sub-circuit defined by the hash table of gates and wires.
+ */
+static void subcircuitBBX(SHash *ghash,NHash *whash,GWireList *wires,
+			  int *minX,int *minY,int *maxX,int *maxY,int append)
+{
+  HashElem *E;
+  GWireList *wl;
+  int is_first = !append;
+
+  /*
+   * This will only be used if this is not an append, and there are no gates or wires.
+   */
+  if (is_first) {
+    *minX = 0;
+    *maxX = 0;
+    *minY = 0;
+    *maxY = 0;
+  }
+
+  if (ghash) {
+    for (E = Hash_first(ghash);E;E = Hash_next(ghash,E)) {
+      GCElement *g = (GCElement *) HashElem_obj(E);
+      int MinX,MinY,MaxX,MaxY;
+
+      gate_getbbx(g,&MinX,&MinY,&MaxX,&MaxY);
+
+      if (is_first || MinX < *minX) *minX = MinX;
+      if (is_first || MaxX > *maxX) *maxX = MaxX;
+      if (is_first || MinY < *minY) *minY = MinY;
+      if (is_first || MaxY > *maxY) *maxY = MaxY;
+      is_first = 0;
+
+    }
+  }
+
+  if (whash) {
+    for (E = Hash_first(whash);E;E = Hash_next(whash,E)) {
+      GWire *w = (GWire *) HashElem_obj(E);
+      GWireNode *n;
+
+      w = w->driver;
+      for (n = w->nodes;n;n = n->out) {
+	int x = n->x;
+	int y = n->y;
+
+	if (is_first || x < *minX) *minX = x;
+	if (is_first || x > *maxX) *maxX = x;
+	if (is_first || y < *minY) *minY = y;
+	if (is_first || y > *maxY) *maxY = y;
+	is_first = 0;
+      }
+    }
+  }
+
+  for (wl = wires;wl;wl = wl->cdr) {
+    GWire *w = wl->car;
+    GWireNode *n;
+
+    w = w->driver;
+    for (n = w->nodes;n;n = n->out) {
+      int x = n->x;
+      int y = n->y;
+
+      if (is_first || x < *minX) *minX = x;
+      if (is_first || x > *maxX) *maxX = x;
+      if (is_first || y < *minY) *minY = y;
+      if (is_first || y > *maxY) *maxY = y;
+      is_first = 0;
+    }
+  }
+
+}
+
 GSelection *new_GSelection()
 {
   GSelection *S = (GSelection*) ob_malloc(sizeof(GSelection),"GSelection");
@@ -132,6 +206,114 @@ void sel_updateMenuState()
   DoTcl(".mbar.edit.menu entryconfigure 6 -state %s",states[paste_ok]);
 }
 
+/*
+ * Rotate the selection.
+ */
+void sel_rotate(EditState *es,int rdir)
+{
+  int minX, minY, maxX, maxY, centX, centY, newcentX, newcentY;
+  GSelection *S = XGate.circuit->mg_selection;
+  HashElem *E;
+
+  if (!S) return;
+
+  if (S->s_hasAnchored) {
+    message(0,msgLookup("err.gatanchor"));		/* Gate(s) are anchored and can not be moved. */
+    return;
+  }
+
+  /*
+   * If there are edge wires, make sure that non are attached to anything.
+   */
+  if (Hash_numElems(S->s_edgeWires) > 0) {
+    int ok = 1;
+
+    for (E = Hash_first(S->s_edgeWires);E;E = Hash_next(S->s_edgeWires,E)) {
+      GWire *w = (GWire*) HashElem_obj(E);
+
+      w = w->driver;
+      if (w->gate && !w->gate->selected)
+	ok = 0;
+
+      w = wire_drivee(w);
+      if (w->gate && !w->gate->selected)
+	ok = 0;
+    }
+
+    if (!ok) {
+      message(0,msgLookup("err.norotation"));
+      return;
+    }
+  }
+
+  SetModified();
+  ob_touch(XGate.circuit);
+
+  subcircuitBBX(S->s_gates, S->s_wires, 0,
+		&minX, &minY, &maxX, &maxY, 0);
+
+  centX = (minX + maxX)/2;
+  centY = (minY + maxY)/2;
+
+  for (E = Hash_first(S->s_wires);E;E = Hash_next(S->s_wires,E)) {
+    GWire *w = (GWire*) HashElem_obj(E);
+    GWireNode *n;
+
+    w = w->driver;
+    for (n = w->nodes;n;n = n->out) {
+      int x = n->x;
+      int y = n->y;
+      ob_touch(n);
+      n->x = rotateX(x - centX,y - centY,rdir) + centX;
+      n->y = rotateY(x - centX,y - centY,rdir) + centY;
+    }
+
+    ob_touch(w);
+    w->orient = (w->orient + 4 + rdir) % 4;
+    w = wire_drivee(w);
+    ob_touch(w);
+    w->orient = (w->orient + 4 + rdir) % 4;
+  }
+  for (E = Hash_first(S->s_edgeWires);E;E = Hash_next(S->s_edgeWires,E)) {
+    GWire *w = (GWire*) HashElem_obj(E);
+    GWireNode *n;
+
+    w = w->driver;
+    for (n = w->nodes;n;n = n->out) {
+      int x = n->x;
+      int y = n->y;
+      ob_touch(n);
+      n->x = rotateX(x - centX,y - centY,rdir) + centX;
+      n->y = rotateY(x - centX,y - centY,rdir) + centY;
+    }
+
+    ob_touch(w);
+    w->orient = (w->orient + 4 + rdir) % 4;
+    w = wire_drivee(w);
+    ob_touch(w);
+    w->orient = (w->orient + 4 + rdir) % 4;
+  }
+
+  for (E = Hash_first(S->s_gates);E;E = Hash_next(S->s_gates,E)) {
+    GCElement *g = (GCElement*) HashElem_obj(E);
+
+    (*g->typeinfo->Rotate)(g,centX,centY,rdir);
+  }
+
+  /*
+   * Compute new center after rotation and nudge it back to the before
+   * rotation center position.  This prevents gates from "walking" as
+   * they are rotated.
+   */
+  subcircuitBBX(S->s_gates, S->s_wires, 0,
+		&minX, &minY, &maxX, &maxY, 0);
+  newcentX = (minX + maxX)/2;
+  newcentY = (minY + maxY)/2;
+  if (newcentX != centX || newcentY != centY) {
+    sel_move(es,centX-newcentX,centY-newcentY);
+  }
+}
+
 int sel_isSelGate(GCElement *g)
 {
   if (!XGate.circuit->mg_selection)
@@ -170,6 +352,16 @@ static void sel_addGate(EditState *es,GCElement *g)
   gate_draw(g,GD_NOWIRE);
 }
 
+int sel_refinish(EditState *es)
+{
+  if (XGate.circuit->mg_selection) {
+    NHash_flush(XGate.circuit->mg_selection->s_wires);
+    NHash_flush(XGate.circuit->mg_selection->s_edgeWires);
+    sel_finish(es);
+  }
+  return 0;
+}
+
 int sel_finish(EditState *es)
 {
   GWireList *wl;
