@@ -1,5 +1,5 @@
 /****************************************************************************
-    Copyright (C) 1987-2005 by Jeffery P. Hansen
+    Copyright (C) 1987-2007 by Jeffery P. Hansen
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    Last edit by hansen on Mon Feb  9 15:39:25 2004
+    Last edit by hansen on Sun Jan 28 12:17:25 2007
 ****************************************************************************/
 #include <stdlib.h>
 #include "tkgate.h"
@@ -119,6 +119,7 @@ GGateInfo gate_tap_info = {
   Generic_HitDistance,
   Tap_Draw,
   Generic_Move,
+  Generic_Rotate,
   Tap_Replicate,
   Err_AddInput,
   Err_AddOutput,
