@@ -1,5 +1,5 @@
 /****************************************************************************
-    Copyright (C) 1987-2005 by Jeffery P. Hansen
+    Copyright (C) 1987-2007 by Jeffery P. Hansen
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -81,6 +81,12 @@ typedef int New_Tcl_CmdProc(ClientData d,Tcl_Interp *tcl,int argc,const char *ar
 typedef Tcl_CmdProc New_Tcl_CmdProc;
 #endif
 
+/*
+ * Rotations
+ */
+#define rotateX(x,y,d) ((y)*(d))
+#define rotateY(x,y,d) (-(x)*(d))
+
 /*
  * Coordinate conversion macros.  The 'ctow' macros convert from circuit
  * to window coordinates while the 'wtoc' mactos convert from window
