@@ -1,5 +1,5 @@
 /****************************************************************************
-    Copyright (C) 1987-2005 by Jeffery P. Hansen
+    Copyright (C) 1987-2007 by Jeffery P. Hansen
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -630,7 +630,7 @@ int VerilogSave(const char *name)
       if (p[-1] != '~') {			/* Don't create backup when editing a backup file */
 	strcpy(p,"~");
 	if (copy_file(name,buf) != 0)
-	  message(1,msgLookup("msg.backupfail"),p);
+	  message(1,msgLookup("err.backupfail"),p);
       }
       doBackupOnSave = 0;
     }
