@@ -1,5 +1,5 @@
 /****************************************************************************
-    Copyright (C) 1987-2005 by Jeffery P. Hansen
+    Copyright (C) 1987-2007 by Jeffery P. Hansen
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -700,3 +700,35 @@ GWire *wire_other(GWire *w)
   else
     return wire_drivee(w);
 }
+
+void wire_rePort(GWire *w,int wx,int wy,int dir)
+{
+  GWire *ow = wire_other(w);
+
+  ob_touch(w);
+  wire_move(w->nodes,wx-w->nodes->x,wy-w->nodes->y,VERTICAL|HORIZONTAL);
+
+  /*
+   * If wire end is not attached, compute mirror image.  Otherwise use brute force
+   * to fix the wire.
+   */
+  if (w->orient != dir) {
+    w->orient = dir;
+    if (!ow->gate) {
+      int cx = w->nodes->x;
+      int cy = w->nodes->y;
+      GWireNode *n;
+
+
+      for (n = w->driver->nodes;n;n = n->out) {
+	ob_touch(n);
+	//	if (g->orient == 0 || g->orient == 2)
+	if (dir == D_LEFT || dir == D_RIGHT)
+	  n->x = cx - (n->x - cx);
+	else
+	  n->y = cy - (n->y - cy);
+      }
+    } else
+      wire_snap(w->driver->nodes);
+  }
+}
