@@ -1,5 +1,5 @@
 /****************************************************************************
-    Copyright (C) 1987-2005 by Jeffery P. Hansen
+    Copyright (C) 1987-2007 by Jeffery P. Hansen
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -207,6 +207,8 @@ void wire_snapgate(GCElement *g,int doRedraw)
   */
 GWireNode *wire_snapendgate(GWire *w,int *mod,int retry)
 {
+  GCElement *g = w->gate;
+  GGateInfo *gi = g->typeinfo;
   int p,n;
   static short dx[] = {-9,0,9,0};
   static short dy[] = {0,9,0,-9};
@@ -215,6 +217,12 @@ GWireNode *wire_snapendgate(GWire *w,int *mod,int retry)
   printf("wire_snapendgate on %s::%s\n",w->gate->typeinfo->englishName,w->gate->ename);
 #endif
 
+  //
+  // See if there is a special snap method 
+  //
+  if (gi->WireSnap)
+    return (*gi->WireSnap)(g,w,mod,retry);
+
   switch (w->gate->typeinfo->Code) {
   default :
     if (posongate(w,w->gate,&p,&n) == 0) {
