@@ -1,5 +1,5 @@
 /****************************************************************************
-    Copyright (C) 1987-2005 by Jeffery P. Hansen
+    Copyright (C) 1987-2007 by Jeffery P. Hansen
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@ void AOX_VerSave(FILE*,GCElement*);
 void AOX_SetProp(GCElement*,const char*,const void*);
 void AOX_EditProps(GCElement *g,int isLoadDialog);
 void AOX_PSWrite(FILE *f,GModLayout*,GCElement *g);
+void AOX_Rotate(GCElement *g,int centX, int centY,int rdir);
 GCElement *AOX_Replicate(GModuleDef *M,GCElement *g,int x,int y,unsigned flags);
 
 static iconDimensions xor_iconDims[] = {
@@ -92,6 +93,7 @@ GGateInfo gate_xor_info = {
   Generic_HitDistance,
   AOX_Draw,
   Generic_Move,
+  AOX_Rotate,
   AOX_Replicate,
   AOX_AddInput,
   Err_AddOutput,
